Weather Reporter
A Python package of TOPSIS.

Usage
Following query on terminal will provide you the TOPSIS.

TOPSIS-NAMAN BANSAL-101803202 python topsis.py inputfile.csv “1,1,1,2” “+,+,-,+” result.csv
